@@ -20,7 +20,7 @@ from knack.util import CLIError, to_snake_case
 
 logger = get_logger(__name__)
 
-CLI_PACKAGE_NAME = 'azure-cli'
+CLI_PACKAGE_NAME = 'msgraph-cli'
 COMPONENT_PREFIX = 'azure-cli-'
 
 SSLERROR_TEMPLATE = ('Certificate verification failed. This typically happens when using Azure CLI behind a proxy '
@@ -252,7 +252,8 @@ def get_installed_cli_distributions():
     # return [d for d in list(working_set) if d.key == CLI_PACKAGE_NAME or d.key.startswith(COMPONENT_PREFIX)]
 
     # Use the hard-coded version instead of querying all modules under site-packages.
-    from azure.cli.core import __msgraph_cli_version__ as azure_cli_core_version
+    from azure.cli.core import __msgraph_cli_version__ as msgraph_cli_core_version
+    from azure.cli.core import __version__ as azure_cli_core_version
     from azure.cli.telemetry import __version__ as azure_cli_telemetry_version
 
     class VersionItem:  # pylint: disable=too-few-public-methods
@@ -262,7 +263,7 @@ def get_installed_cli_distributions():
             self.version = version
 
     return [
-        VersionItem('msgraph-cli', azure_cli_core_version),
+        VersionItem('msgraph-cli', msgraph_cli_core_version),
         VersionItem('azure-cli-core', azure_cli_core_version),
         VersionItem('azure-cli-telemetry', azure_cli_telemetry_version)
     ]
@@ -434,20 +435,22 @@ def show_updates_available(new_line_before=False, new_line_after=False):
     VERSIONS[_VERSION_CHECK_TIME] = str(datetime.datetime.now())
 
 
+# Disabling show_updated until when we can support this functionality
 def show_updates(updates_available_components, only_show_when_updates_available=False):
-    if updates_available_components is None:
-        if not only_show_when_updates_available:
-            logger.warning('Unable to check if your CLI is up-to-date. Check your internet connection.')
-    elif updates_available_components:  # pylint: disable=too-many-nested-blocks
-        if in_cloud_console():
-            warning_msg = 'You have %i updates available. They will be updated with the next build of Cloud Shell.'
-        else:
-            warning_msg = "You have %i updates available."
-            if CLI_PACKAGE_NAME in updates_available_components:
-                warning_msg = "{} Consider updating your CLI installation with 'az upgrade'".format(warning_msg)
-        logger.warning(warning_msg, len(updates_available_components))
-    elif not only_show_when_updates_available:
-        print('Your CLI is up-to-date.')
+    # if updates_available_components is None:
+    #     if not only_show_when_updates_available:
+    #         logger.warning('Unable to check if your CLI is up-to-date. Check your internet connection.')
+    # elif updates_available_components:  # pylint: disable=too-many-nested-blocks
+    #     if in_cloud_console():
+    #         warning_msg = 'You have %i updates available. They will be updated with the next build of Cloud Shell.'
+    #     else:
+    #         warning_msg = "You have %i updates available."
+    #         if CLI_PACKAGE_NAME in updates_available_components:
+    #             warning_msg = "{} Consider updating your CLI installation with 'az upgrade'".format(warning_msg)
+    #     logger.warning(warning_msg, len(updates_available_components))
+    # elif not only_show_when_updates_available:
+    #     print('Your CLI is up-to-date.')
+    pass
 
 
 def get_json_object(json_string):
